{% extends "part/main.html" %}

{% block main %}
<div class="ac-bangumi-list">
    <div id="bangumiList">
        <div class="ac-mod-list">
            <ul class="ac-mod-ul"></ul>
        </div>
    </div>
</div>
{% endblock main %}
