{% set RAW = saver.ac_obj.raw_data %}{% set UP = saver.ac_obj.up().raw_data %}{% set source = saver.ac_obj.source_obj %}
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="referer" content="{{ saver.ac_obj.referer }}">
    <title>@{{ RAW.user.name }}动态 - AcSaver</title>
    <link type="image/ico" rel="shortcut icon" href="../../assets/favicon.ico">
    <link type="text/css" rel="stylesheet" href="../../assets/css/moment.css"/>
</head>
<body>
    <div id="app">
        <div class="layout">
            <header id="header"></header>
            <main>
                <div class="ac-moment">
                    <div class="ac-moment-wrap">
                        <div class="ac-moment-feed">
                            <div class="member-feed-user">
                                <div class="feed-up">
                                    <div class="feed-up-avatar">
                                        <a href="https://www.acfun.cn/u/{{ RAW.user.href }}" target="_blank">
                                            <img src="../../member/{{ RAW.user.href }}_avatar" onerror="this.src='../../assets/img/defaultAvatar.jpg';" alt="{{ RAW.user.name }}">
                                            <div class="live-status">直播</div>
                                        </a>
                                        <div class="ac-trigger-content" style="min-width: 0px; display: none;"></div>
                                    </div>
                                    <div class="feed-up-info">
                                        <div class="up-name no-color">
                                            <a href="https://www.acfun.cn/u/{{ RAW.user.href }}" target="_blank" {% if RAW.user.nameColor == 1 %} style="{{ RAW.user.nameStyle }}"{% endif %}
                                               class="text-overflow">{{ RAW.user.name }}</a>
                                            <div class="ac-trigger-content" style="min-width: 0px; display: none;"></div>
                                        </div>
                                        <div class="verify">
                                            {% if 1 in RAW.user.verifiedTypes %}
                                            <span class="ac-icon ac-icon-small">
                                                <img src="../../assets/img/icon_monkey_new.svg" class="icon-img" alt="AcFun管理员认证" title="AcFun官方认证">
                                            </span>
                                            {% endif %}
                                            {% if 2 in RAW.user.verifiedTypes %}
                                            <span class="ac-icon ac-icon-small">
                                                <img src="../../assets/img/icon_v.svg" class="icon-img" alt="AcFun官方认证" title="AcFun官方认证">
                                            </span>
                                            {% endif %}
                                            {% if 3 in RAW.user.verifiedTypes %}
                                            <span class="ac-icon ac-icon-small">
                                                <img src="../../assets/img/icon_avi.svg" class="icon-img" alt="AVI虚拟偶像标识" title="AVI虚拟偶像标识">
                                            </span>
                                            {% endif %}
                                            {% if 4 in RAW.user.verifiedTypes %}
                                            <span class="ac-icon ac-icon-small">
                                                <img src="../../assets/img/icon_gjdm.svg" class="icon-img" alt="高弹达人标识" title="高弹达人标识">
                                            </span>
                                            {% endif %}
                                            {% if 5 in RAW.user.verifiedTypes %}
                                            <span class="ac-icon ac-icon-small ac-icon-academy">
                                                <img src="../../assets/img/icon_up.svg" class="icon-img" alt="阿普学院标志">
                                            </span>
                                            <div class="ac-trigger-content ac-verify-icon-dropdown" style="min-width: 0px; margin: 0px; display: none;">
                                                <div>
                                                    <p style="color: rgb(153, 153, 153);">尊贵的阿普学院标志</p>
                                                    <a rel="noopener" href="//member.acfun.cn/academy" target="_blank" class="link" style="display: block;">如何获得标志？</a>
                                                </div>
                                                <div data-popper-arrow="true" class="ac-trigger-content-arrow"><span></span></div>
                                            </div>
                                            {% endif %}
                                        </div>
                                        <span class="feed-time">{{ RAW.createTime }}</span>
                                    </div>
                                </div>
                            </div>
                            <div class="feed-content">
                                <div class="member-feed-moment">
                                    <a id="srcUrl" href="{{ saver.ac_obj.referer }}"></a>
                                    <div class="member-feed-text">{{ saver.html_content }}</div>
                                    {% if RAW.get('imgs', [])|length %}{% set momentImages = saver.images %}
                                    <div class="member-feed-moment-image member-feed-moment-image-{{ momentImages|length }}">
                                        {% for img in momentImages %}
                                        <img src="{{ img.originUrl }}" alt="">
                                        {% endfor %}
                                        <div><!----></div>
                                    </div>
                                    {% endif %}
                                    {% if "repostSource" in RAW %}{% set source = saver.ac_obj.source_obj %}{% set repost = RAW.repostSource %}
                                    <div class="member-feed-repost-content">
                                        <div class="repost-up">
                                            <a href="https://www.acfun.cn/u/{{ repost.user.userId }}">
                                            <span class="up-name">@{{ repost.user.userName }}</span>
                                            <span class="follow">关注</span>
                                            </a>
                                        </div>
                                        <div class="member-feed-resource" data-impr-show="true">
                                            <div class="member-feed-text"></div>
                                            {% if repost.resourceType in [2, 3] %}
                                            <div id="member-feed-resource-data" datatype="{{ [0, 0, 'video', 'article'][repost.resourceType] }}" datasrc="{{ repost.resourceId }}"></div>
                                            <div class="member-feed-resource-content">
                                                <div class="content-left">
                                                    <a href="{{ repost.shareUrl }}" class="member-feed-resource-link">
                                                    <img src="{{ repost.coverUrl }}" alt="" class="cover">
                                                    <span class="resource-tag">{{ rtype_names[repost.resourceType|string] }}</span>
                                                    {% if repost.resourceType == 2 %}
                                                    <div class="video-time">{{ repost.playDuration }}</div>
                                                    {% endif %}
                                                    </a>
                                                </div>
                                                <div class="content-right">
                                                    <a href="{{ repost.shareUrl }}" class="member-feed-resource-link">
                                                    <h1 class="title text-overflow feed-link">{{ repost.caption or repost.articleTitle }}</h1>
                                                    {% if repost.resourceType == 2 %}
                                                    <div class="desc">{{ repost.detail.description }}</div>
                                                    {% elif repost.resourceType == 3 %}
                                                    <div class="desc">{{ repost.articleBody }}</div>
                                                    {% endif %}
                                                    <div class="info">
                                                        {% if repost.resourceType == 2 %}
                                                        <span class="view"><span class="ac-icon"><i class="iconfont">&#xe62f;</i></span>{{ repost.viewCount }}</span>
                                                        <span class="danmu"><span class="ac-icon"><i class="iconfont">&#xe630;</i></span>{{ repost.detail.danmakuCount }}</span>
                                                        {% elif repost.resourceType == 3 %}
                                                        <span class="view"><span class="ac-icon"><i class="iconfont">&#xe1a8;</i></span>{{ repost.viewCount }}</span>
                                                        <span class="danmu"><span class="ac-icon"><i class="iconfont">&#xe627;</i></span>{{ repost.commentCount }}</span>
                                                        {% endif %}
                                                    </div>
                                                    </a>
                                                </div>
                                            </div>
                                            {% endif %}
                                        </div>
                                    </div>
                                    {% endif %}
                                </div>
                            </div>
                            <div class="member-feed-interactive">
                                <div class="feed-interactive">
                                    <div class="feed-interactive-comment active">
                                        <span class="ac-icon"><i class="iconfont"></i></span>
                                        <span>{{ RAW.commentCount }}</span>
                                    </div>
                                    <div class="feed-interactive-banana">
                                        <span class="icon_path ac-icon"><i class="iconfont"></i></span>
                                        <span class="icon_fill ac-icon"><i class="iconfont"></i></span>
                                        <span>{{ RAW.bananaCount }}</span>
                                    </div>
                                    <div class="feed-interactive-like">
                                        <span class="icon_path ac-icon"><i class="iconfont"></i></span>
                                        <span class="icon_fill ac-icon"><i class="iconfont"></i></span>
                                        <span>{{ RAW.likeCount }}</span>
                                    </div>
                                    <div class="feed-interactive-repost">
                                        <span class="ac-icon"><i class="iconfont"></i></span>
                                        <span>{{ RAW.shareCount }}</span>
                                        <div class="ac-trigger-content" data-popper-placement="bottom-start">
                                            <div class="member-feed-share">
                                                <div class="share-title">分享本动态给朋友吧</div>
                                                <div class="share-action-area">
                                                    <div class="share-action-area-left">
                                                        <div class="qrcode"><img src="data/mobile_qrcode.png" alt="" onerror="this.src='../../assets/img/404img.png';"></div>
                                                        <p>打开右侧app</p><p>扫码转发</p>
                                                    </div>
                                                    <div class="share-action-area-right">
                                                        <div class="share-type">
                                                            <a class="share-icon acfun-app"></a>
                                                            <a title="分享到百度贴吧" data-cmd="tieba" data-plat="OTHER" class="share-icon bds_tieba"></a>
                                                            <a title="分享到新浪微博" data-cmd="tsina" data-plat="WEIBO" class="share-icon weibo bds_tsina"></a>
                                                            <a title="分享到QQ空间" data-cmd="qzone" data-plat="QQ_FRIENDZONE" class="share-icon qzone bds_qzone"></a>
                                                        </div>
                                                        <p>分享动态到博客或论坛</p>
                                                        <div class="share-copy">
                                                            <input aria-label="" readonly="readonly" class="share-copy-content" value="{{ saver.ac_obj.referer }}">
                                                            <div class="share-copy-btn" onclick="SAVER.utils.copyText('{{ saver.ac_obj.referer }}')">复制动态地址</div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="pagelet_newcomment" style="visibility: visible;"></div>
                            </div>
                            <div class="feed-more"><span class="ac-icon"><i class="iconfont"></i></span></div>
                        </div>
                    </div>
                </div>
            </main>
        </div>
    </div>
<div id="pagelet_footer" style="visibility: visible;"></div>
<div id="pagelet_toolbar" style="visibility: visible;"></div>
<script type="text/javascript" src="../../assets/js/acsaver.js"></script>
</body>
</html>
