<div id="pagelet_toolbar" style="visibility: visible;">
    <div id="toolbar" class="toolbar showAll">
        <a href="#app">
            <div id="to-top" title="返回顶部" class="icon icon-arrow-slim-up tool-item tool-to-top toBottom"></div>
        </a>
    </div>
</div>
