<nav class="ac-member-navigation">
    <a href="https://www.acfun.cn/" target="_blank" aria-current="page" class="ac-member-navigation-item">
        <span class="ac-icon"><i class="iconfont">&#xe3c9;</i></span> AcFun首页</a>
    <a href="index.html" class="ac-member-navigation-item">
        <span class="ac-icon"><i class="iconfont">&#xe3c5;</i></span> 视频文章</a>
    <a href="anime.html" class="ac-member-navigation-item">
        <span class="ac-icon"><i class="iconfont">&#xe3cb;</i></span> 番剧</a>
    <a aria-current="page" class="ac-member-navigation-item ac-member-navigation-item-active">
        <span class="ac-icon"><i class="iconfont">&#xe3c4;</i></span> 动态</a>
</nav>
