<header id="header" style="width: 100%;margin: 0;">
    <div class="nav" style="width: 1190px;">
        <div class="nav-links">
            <a href="https://www.acfun.cn/" class="logo">
                <img src="assets/img/acfunlogo.svg" alt="" width="94" height="30"></a>
        </div>
        <div class="nav-title" style="display:none;"><a href=""></a></div>
        <div class="nav-bread"></div>
        <div class="nav-guide" style="display:none;">
            <span class="nav-guide-main">导航<span class="ac-icon"><i class="iconfont"></i></span></span>
            <ul class="nav-guide-2"><div class="nav-guide-3-place"></div></ul>
        </div>
        <div class="nav-entrance-wrap">
            <a href="index.html" class="nav-mall">
                <span class="ac-icon"><i class="iconfont">&#xe3c5;</i></span>
                <span class="entrance-title">视频文章</span></a>
            <a href="anime.html" class="nav-mall">
                <span class="ac-icon"><i class="iconfont">&#xe3cb;</i></span>
                <span class="entrance-title">番剧</span></a>
            <a href="feed.html" class="face-catcher">
                <span class="ac-icon"><i class="iconfont">&#xe3c4;</i></span>
                <span class="entrance-title">动态</span></a>
        </div>
        <div class="nav-search">
            <span class="nav-search-input ac-input-wrapper ac-input-suffix">
                <input aria-label="" placeholder="" autocomplete="off" minlength="" maxlength="" type="text" value="" class="ac-input" id="nav-search">
                <div class="ac-input-suffix-item" id="nav-search-btn"><span class="ac-icon"><i class="iconfont"></i></span></div>
            </span>
        </div>
        <div class="nav-user">
            <a href="https://github.com/dolaCmeo/acfunsdk" target="_blank" class="nav-user-item">
                <span class="icon ac-icon"><i class="iconfont">&#xe353;</i></span>
                <p class="desc">AcSDK</p></a>
            <a href="https://github.com/dolaCmeo/acsaver" target="_blank" class="nav-user-item">
                <span class="icon ac-icon"><i class="iconfont">&#xe62e;</i></span>
                <p class="desc">AcSaver</p></a>
            <a href="https://www.acfun.cn" target="_blank" rel="noopener" class="user-upload" id='online-link'>
                <button type="button" class="ac-button ac-button-primary ac-button-normal">
                    <span class="ac-icon" style="margin-right:4px;"><i class="iconfont">&#xe3c9;</i></span> 去线上
                </button></a>
        </div>
    </div>
</header>
