<!DOCTYPE html>
<html lang="zh">
<head>{% set RAW = saver.ac_obj.raw_data %}{% set UP = saver.ac_obj.up().raw_data %}
    <meta charset="UTF-8">
    <meta name="referer" content="{{ saver.ac_obj.referer }}">
    <title>{{ RAW.title }} - AcSaver</title>
    <link type="image/ico" rel="shortcut icon" href="../../assets/favicon.ico">
    <link type="text/css" rel="stylesheet" href="../../assets/css/video.css"/>
</head>
<body>
<header id="header"></header>
<div id="main" class="single-part">
    <div id="main-content" class="clearfix" style="margin: 0 auto;">
        <div class="left-column">
            <div class="player-box" id="player-box"></div>
            <div class="video-description clearfix dark-style">
                <h1 class="title">
<!--                    <a class="reco-tag" href="https://www.acfun.cn/rank/list/#cid=-1;range=1;pcid=-3" title="综合榜Top2" target="_blank">综合榜Top2</a>-->
                    <a id="srcUrl" href="https://www.acfun.cn/v/ac{{ saver.rid }}" style="cursor: default;"><span>{{ RAW.title }}</span></a>
                </h1>
                <div class="action-area">
                    <div class="left-area">
                        {% if RAW.originalDeclare %}
                        <div class="originalDeclare" style="display: inline-block;"><span class="originalDeclareText icon-ks icon-icon_-jin-zhi-zhuan-zai">未经作者授权，禁止转载</span></div>
                        {% endif %}
                        <div class="views"><span class="viewsCount" title="{{ RAW.viewCount }}">{{ RAW.viewCountShow }}</span>播放</div>
                        <div class="danmu"><span class="danmuCount sp2" title="{{ RAW.danmakuCount }}">{{ RAW.danmakuCountShow }}</span>弹幕</div>
                        <div class="comment"><span class="commentCount" title="{{ RAW.commentCount }}">{{ RAW.commentCountShow }}</span>评论</div>
                        <div class="cache"><span>{{ None|unix2datestr }}</span><span>缓存</span></div>
                    </div>
                    <div class="right-area">
                        <div class="like"><span class="icon"></span><span class="likeCount" title="{{ RAW.likeCount }}">{{ RAW.likeCountShow }}</span></div>
                        <div class="collection"><span class="icon"></span><span class="collectionCount" title="{{ RAW.stowCount }}">{{ RAW.stowCountShow }}</span></div>
                        <div class="banana"><span class="icon"></span><span class="bananaCount" title="{{ RAW.bananaCount }}">{{ RAW.bananaCountShow }}</span></div>
                        <div class="share"><span class="icon"></span><span title="{{ RAW.shareCount }}">{{ RAW.shareCountShow }}</span>
                            <div class="share-module">
                                <div class="share-title">分享本视频给朋友吧</div>
                                <div class="share-action-area">
                                    <div class="share-left-area">
                                        <div class="qrcode"><img src="data/share_qrcode.png" alt=""></div>
                                        <p class="scan">扫一扫</p><p>分享到微信/朋友圈</p>
                                    </div>
                                    <div class="share-right-area">
                                        <div class="share-type"></div>
                                        <div class="share-container">
                                            <div id="share-component">
                                                <div class="share-desc">获取原视频地址</div>
                                                <div class="area-share clearfix">
                                                    <input aria-label="" id="videoUrl" class="ipt-url fl" type="text" readonly="readonly" value="https://www.acfun.cn/v/ac{{ saver.rid }}">
                                                    <span data-clipboard-target="#videoUrl" class="copy fl cp-url" onclick="SAVER.utils.copyText('https://www.acfun.cn/v/ac{{ saver.rid }}')">复制</span>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="mobile" style="display: inline-block;"><span class="icon"></span>
                            <div class="mobile-module">
                                <div class="mobile-title">手机扫码观看视频</div>
                                <div class="mobile-action-area">
                                    <div class="mobile-left-area">
                                        <div class="qrcode">
                                            <img src="data/mobile_qrcode.png">
                                        </div>
                                        <p>扫一扫手机继续观看</p></div>
                                    <div class="mobile-right-area"><p>{{ RAW.title }}</p></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="introduction">
                <div class="up-area">{% set hasStaffContribute = RAW.get('staffContribute') == True %}
                    {% if not hasStaffContribute %}
                    <div class="up-details">
                        <a href="https://www.acfun.cn/u/{{ RAW.user.href }}" class="up-avatar up-avatar-wrapper" target="_blank">
                            <img src="../../member/{{ RAW.user.href }}_avatar" onerror="this.src='../../assets/img/defaultAvatar.jpg';" class="avatar live-avatar" alt="">
                        </a>
                        <div class="up-data">
                            <div class="up-info">
                                <a class="up-name" href="https://www.acfun.cn/u/{{ RAW.user.href }}" target="_blank" title="注册于 {{ UP.registerTime|unix2datestr }}"
                                        {% if RAW.user.nameColor == 1 %} style="{{ RAW.user.nameStyle }}"{% endif %}>{{ RAW.user.name }}</a>
                                {% if 1 in RAW.user.verifiedTypes %}
                                <span class="verified-icon monkey-verified-icon" title="AcFun管理员认证"></span>
                                {% endif %}
                                {% if 2 in RAW.user.verifiedTypes %}
                                <span class="verified-icon official-verified-icon" title="{{ "AcFun官方认证\n"|safe + RAW.user.verifiedText or '' }}"></span>
                                {% endif %}
                                {% if 3 in RAW.user.verifiedTypes %}
                                <span class="verified-icon avi-verified-icon" title="AVI虚拟偶像标识"></span>
                                {% endif %}
                                {% if 4 in RAW.user.verifiedTypes %}
                                <span class="verified-icon advanced-danmaku-verified-icon" title="高弹达人标识"></span>
                                {% endif %}
                                {% if 5 in RAW.user.verifiedTypes %}
                                <span class="up-college-verified verified-icon">
                                    <span class="verified-icon up-college-verified-icon"></span>
                                    <span class="up-college-verified-content">
                                        <span class="up-college-verified-content-text">尊贵的阿普学院标志
                                            <a rel="noopener" class="link" href="//member.acfun.cn/academy" target="_blank">如何获得标志？</a>
                                        </span>
                                    </span>
                                </span>
                                {% endif %}
                            </div>
                            <div class="publish-time">发布于&nbsp;{{ RAW.createTimeMillis|unix2datestr }}</div>
                        </div>
                    </div>
                    {% else %}
                        <div class="up-details staff-details">
                            <a href="/u/{{ RAW.user.href }}" class="up-avatar up-avatar-wrapper" target="_blank">
                                <img src="../../member/{{ RAW.user.href }}_avatar" class="avatar live-avatar">
                            </a>
                            <a href="/u/{{ RAW.user.href }}" class="up-name">{{ RAW.user.name }}</a>
                            <div class="role">{{ RAW.upInfo.staffRoleName }}</div><div class="follow hidden">+</div>
                        </div>
                    {% for staff in RAW.get('staffInfos') %}
                    <div class="staff-details">
                        <div>
                            <a href="https://www.acfun.cn/u/{{ staff.href }}" target="_blank" class="staff-avatar">
                                <img alt="{{ staff.verifiedText }}" src="../../member/{{ staff.href }}_avatar" class="avatar live-avatar">
                            </a>
                        </div>
                        <a href="https://www.acfun.cn/u/{{ staff.href }}" class="staff-name">{{ staff.name }}</a>
                        <div class="role">{{ staff.staffRoleName }}</div><div class="follow hidden">+</div>
                    </div>
                    {% endfor %}
                    {% endif %}
                    <div class="up-interactive">
                        <div class="follow-up not-follow" title="{{ RAW.fanCountValue }}">关注&nbsp;{{ RAW.user.fanCount }}</div>
<!--                            <div class="btn-reward">鼓励</div>-->
                    </div>
                </div>
                <div class="content-description">
                    <div class="description-container">{{ RAW.description or "" }}</div>
                    <div class="originalLink">{{ RAW.originalLinkUrl or "" }}</div>
                    <div class="tag" id="bd_tag">
                        {% for tag in RAW.tagList %}
                        <span class="tag-single fl">
                            <a href="https://www.acfun.cn/search?keyword={{ tag.name }}" data-tid="{{ tag.id }}" target="_blank" class="fl">{{ tag.name }}</a>
                        </span>
                        {% endfor %}
                    </div>
                </div>
            </div>
            <div class="pagelet_newcomment" style="visibility: visible;"></div>
        </div>
        <div class="right-column">
            <div id="danmaku" class="pagelet_danmaku" style="visibility: visible;"></div>
            <div id="pagelet_partlist"{% if RAW.videoList|length < 2 %} style="display: none{% endif %};">
                <div class="part">
                    <div class="part-title"><h3>分段列表</h3>
                        <p>共{{ RAW.videoList|length }}P, 当前正在播放<span class="current-priority">1</span>P</p></div>
                    <div class="fl part-wrap">
                        <ul class="scroll-div">
                            {% for part in RAW.videoList %}
                            <li class="single-p{% if loop.first %} active{% endif %}" data-index="{{ loop.index0 }}"
                                data-href="{{ RAW.dougaId }}{{ "_"+loop.index|string if loop.index > 1 else "" }}"
                                title="{{ RAW.title }}" data-id="{{ RAW.dougaId }}" data-vid="{{ part.id }}"
                                data-title="{{ part.title }}">{{ part.title }}</li>
                            {% endfor %}
                        </ul>
                    </div>
                </div>
            </div>
            <div id="pagelet_newrecommend" style="display: none">
                <div class="recmd">
                    <h2 class="recommend-title">最新保存</h2>
                    <div class="clearfix area recommendation" id="recommends"></div>
                </div>
            </div>
        </div>
    </div>
</div>
<div id="pagelet_toolbar" style="visibility: visible;"></div>
<div id="pagelet_footer" style="visibility: visible;"></div>
<script type="text/javascript" src="../../assets/js/acsaver.js"></script>
</body>
</html>
