<div id="pagelet_footer" style="visibility: visible;">
    <div id="footer">
        <div class="wp footer-con">
            <div class="footer-bottom">
                <a href="https://www.acfun.cn">
                    <img src="assets/img/logo-gray.png" width="78" height="24" loading="lazy" alt=""></a>
                <p>Copyright © 2007-<script>document.write(new Date().getFullYear().toString())</script> AcFun. 保留所有权利</p></div>
        </div>
    </div>
</div>
